import logging
from typing import Optional

import httpx
from django.conf import settings

from wdg_core_payment._objects import KHQRRequest, KHQRResponse


class CreateKHQRService:
    def __init__(self):
        self.api_url = getattr(settings, "CREATE_KHQR_ENDPOINTS", None)

    def generate_khqr(
        self,
        access_token: str,
        khqr_data: KHQRRequest,
    ) -> Optional[KHQRResponse]:
        """Send KHQR generation request and return the response."""

        with httpx.Client() as client:
            try:
                headers = {
                    "Authorization": f"Bearer {access_token}",
                    "Content-Type": "application/json",
                }

                response = client.post(self.api_url, json=khqr_data, headers=headers)
                response.raise_for_status()
                response_data = response.json()

                # Return the parsed response
                return KHQRResponse(
                    error_code=response_data.get("error_code"),
                    amount=response_data.get("amount"),
                    currency=response_data.get("currency"),
                    khqr=response_data.get("khqr"),
                    error_text=response_data.get("error_text"),
                    merchant_name=response_data.get("merchant_name"),
                    merchant_id=response_data.get("merchant_id"),
                    item_name=response_data.get("item_name"),
                )
            except httpx.HTTPStatusError as e:
                logging.error(f"HTTP error occurred: {e}")
            except httpx.RequestError as e:
                logging.error(f"Request error occurred: {e}")
            return None
