import logging
from typing import Optional

import httpx
from django.conf import settings

from wdg_core_payment._objects import OAuthToken


class OAuthService:
    def __init__(self):
        # Fetch OAuth credentials from Django settings
        self.username = getattr(settings, "WING_USERNAME", None)
        self.password = getattr(settings, "WING_PASSWORD", None)
        self.client_id = getattr(settings, "WING_CLIENT_ID", None)
        self.client_secret = getattr(settings, "WING_CLIENT_SECRET", None)
        self.grant_type = getattr(settings, "WING_GRANT_TYPE", "password")
        self.token_url = getattr(settings, "REQUEST_ACCESS_TOKEN_ENDPOINTS", None)
        
    def get_access_token(self) -> Optional[OAuthToken]:
        """Get the access token from the OAuth provider."""
        with httpx.Client() as client:
            data = {
                "grant_type": self.grant_type,
                "username": self.username,
                "password": self.password,
                "client_id": self.client_id,
                "client_secret": self.client_secret,
            }

            try:
                response = client.post(self.token_url, data=data)
                response.raise_for_status()
                token_data = response.json()
                
                # Return token data in the OAuthToken format
                return OAuthToken(
                    access_token=token_data.get("access_token"),
                    token_type=token_data.get("token_type"),
                    expires_in=token_data.get("expires_in"),
                    scope=token_data.get("scope"),
                )
            except httpx.HTTPStatusError as e:
                logging.error(f"HTTP error occurred: {e}")
            except httpx.RequestError as e:
                logging.error(f"Error while requesting token: {e}")

        return None
